@@ -67,17 +67,17 @@ function (Ymat, Xmat, Xpred)
         ncol = dim(YYY)[2])
     assign("gr.predmask", gr.predmask, pos = 1)
     cat("done", "\n")
-    cat("Creating gr.predmat...", "\n")
+    cat("Creating gr.predmat...")
     gr.predmat <- as.data.frame(matrix(as.single(rep(-99.9, dim(XXXpred)[1] * 
         dim(YYY)[2])), ncol = dim(YYY)[2]))
     assign("gr.predmat", gr.predmat, pos = 1)
     fixed <- rep(1, dim(XXX)[1] * dim(YYY)[2])
     assign("fixed", fixed, pos = 1)
+    cat("done", "\n")
     Yname <- names(YYY[gr.selY])
     cat("SELECTED RESPONSES:", Yname, "\n")
     WEIGHTS <- data.frame(index = YYY[1], Yname = rep(1, dim(XXX)[1]))
     assign("WEIGHTS", WEIGHTS, pos = 1)
-    cat("done", "\n")
     cat("GRASP-R initialized!", "\n")
     cat("\n")
     cat("**********         R-GRASP IN END          **********", 
