@@ -9,7 +9,7 @@ function ()
         pred.sel <- tclvalue(pred.sel)
         write(pred.sel, file = "resp")
         pred.sel <- scan(file = "resp")
-        gr.selX <- pred.sel + 1
+        gr.selX <- pred.sel + 4
         assign("gr.selX", gr.selX, pos = 1)
         assign("gr.Xi", gr.selX, pos = 1)
         assign("SelX", gr.selX, pos = 1)
@@ -26,19 +26,16 @@ function ()
     frame1.label <- tklabel(frame1, text = "Select predictors", 
         justify = "left", wraplength = 200)
     tkpack(frame1, frame1.label, fill = "x")
-    frame2.yscroll <- tkscrollbar(frame2)
+    frame2.yscroll <- tkscrollbar(frame2, repeatinterval=5, command=function(...)tkyview(frame2.lstbox1,...))
     frame2.lstbox1 <- tklistbox(frame2, selectmode = "multiple", 
-        exportselection = FALSE)
-    tkconfigure(frame2.lstbox1, yscrollcommand = paste(.Tk.ID(frame2.yscroll), 
-        "set"))
-    tkconfigure(frame2.yscroll, command = paste(.Tk.ID(frame2.lstbox1), 
-        "yview"))
-    for (i in c(1:length(XXX))) {
+        exportselection = FALSE,yscrollcommand=function(...)tkset(frame2.yscroll,...))
+    for (i in c(4:length(XXX))) {
         tkinsert(frame2.lstbox1, "end", names(XXX)[i])
     }
-    gr.selX0 <- gr.selX - 1
+    gr.selX0 <- gr.selX - 4
     for (i in gr.selX0) tkselection.set(frame2.lstbox1, i)
     tkgrid(frame2.lstbox1, frame2.yscroll)
+    tkgrid.configure(frame2.yscroll, rowspan=4, sticky="nsw")
     tkpack(frame2, fill = "y")
     apply.but <- tkbutton(frame3, text = "Apply", command = apply.predictors)
     close.but <- tkbutton(frame3, text = "Close", command = predsel.close)
